/*
 *
 *
 * @param rowstr
 * @param cookie
 * @param public_gateway_mode
 */
function ThreadInfoManager(csv, cookie, public_gateway_mode) {
	this.threadInfoArray = new Array();
	
	//初期処理-------------------------
	var rowstrArray = csv.split("\r\n");
	
	for(var i = 0; i < rowstrArray.length; i++) {
		var temp = new ThreadInfo(rowstrArray[i], cookie, public_gateway_mode);
		
		if(temp.file) {
			this.threadInfoArray.push(temp);
		}
	}
	//--------------------------------
	
	/*
	 * スレッドに付与されているタグのリストを返します。
	 *
	 * @return タグ文字列の配列
	 */
	this.getTagList = function() {
		var tagArray = new Array();
		
		for(var i = 0; i < this.threadInfoArray.length; i++) {
			if(this.threadInfoArray[i].sugtag && this.threadInfoArray[i].sugtag.match(/[^\s]/)) {
				
				var temp = this.threadInfoArray[i].sugtag.split(" ");
				
				for(var j = 0; j < temp.length; j++) {
					if(!contain(tagArray, temp[j]))
						tagArray.push(temp[j]);
				}
			}
			
			if(this.threadInfoArray[i].tag && this.threadInfoArray[i].tag.match(/[^\s]/)) {
				
				var temp = this.threadInfoArray[i].tag.split(" ");
				
				for(var j = 0; j < temp.length; j++) {
					if(!contain(tagArray, temp[j]))
						tagArray.push(temp[j]);
				}
			}
		}
		
		return tagArray;
	}
	
	/*
	 *
	 */
	this.getThreadInfo = function(index) {
		return this.threadInfoArray[index];
	}
	
	/*
	 *
	 */
	this.getThreadInfoByTitle = function(title) {
		var info = null;
		
		for(var i = 0; i < this.threadInfoArray.length; i++) {
			if(this.threadInfoArray[i].title == title) {
				info = this.threadInfoArray[i];
				break;
			}
		}
		
		return info;
	}
	
	/*
	 * タグ、フィルタによりスレを抽出し、ソーと処理を行ったスレッドの配列を返します。
	 */
	this.getThreadInfoList = function(tag, filter, sortType) {
		var thArray = new Array();
		
		//タグ、フィルタから抽出
		thArray = this.getThreadInfoListByTagAndFilter(tag, filter);
		
		//ソーと処理
		this.sort(thArray, sortType);
		
		return thArray;
	}
	
	/*
	 *
	 */
	this.getThreadInfoListByTagAndFilter = function(tag, filter) {
		var thArray = new Array();
		
		for(var i = 0; i < this.threadInfoArray.length; i++) {
			if(!tag && !filter) {
				thArray.push(this.threadInfoArray[i]);
			} else if(tag && !filter && this.threadInfoArray[i].getTagAndSugtag().match(new RegExp(tag, "i")) ) {
				thArray.push(this.threadInfoArray[i]);
			} else if(!tag && filter && this.threadInfoArray[i].title.match(new RegExp(filter, "i")) ) {
				thArray.push(this.threadInfoArray[i]);
			} else if(tag && filter && this.threadInfoArray[i].getTagAndSugtag().match(new RegExp(tag, "i")) && this.threadInfoArray[i].title.match(new RegExp(filter, "i")) ) {
				thArray.push(this.threadInfoArray[i]);
			}
		}
		
		return thArray;
	}
	
	/*
	 *
	 * @return スレッド数
	 */
	this.length = function() {
		return this.threadInfoArray.length;
	}
	
	/*
	 *
	 *
	 *
	 */
	this.sort = function(thArray, sortType) {
		var temp;
		
		if(sortType.direction == DESCEND) {
			for(var i = 0; i < thArray.length; i++) {
				
				for(var j = i + 1; j < thArray.length; j++) {
					var val1 = thArray[i].getPropertyForSort(sortType.category);
					var val2 = thArray[j].getPropertyForSort(sortType.category);
					
					if(val1 < val2) {
						temp = thArray[j];
						thArray[j] = thArray[i];
						thArray[i] = temp;
					}
				}
			}
		} else {
			for(var i = 0; i < thArray.length; i++) {
				
				for(var j = i + 1; j < thArray.length; j++) {
					var val1 = thArray[i].getPropertyForSort(sortType.category);
					var val2 = thArray[j].getPropertyForSort(sortType.category);
					
					if(val1 > val2) {
						temp = thArray[j];
						thArray[j] = thArray[i];
						thArray[i] = temp;
					}
				}
			}
		}
	}
}

/*
 *
 *
 * @param rowstr
 * @param cookie
 * @param public_gateway_mode
 */
function ThreadInfo(rowstr, cookie, public_gateway_mode) {
	//プロパティ
	this.file = "";
	this.stamp = "";
	this.date = "";
	this.path = "";
	this.uri = "";
	this.type = "";
	this.title = "";
	this.records = "";
	this.size = "";
	this.tag = "";
	this.sugtag = "";
	this.status = 0;
	
	//初期処理------------------------------
	var infoArray = rowstr.split(",");
	
	try {
		this.file = infoArray[0];
		this.stamp = infoArray[1];
		this.date = infoArray[2];
		this.path = infoArray[3];
		this.uri = infoArray[4];
		this.type = infoArray[5];
		this.title = infoArray[6];
		this.records = infoArray[7];
		this.size = infoArray[8];
		this.tag = infoArray[9];
		this.sugtag = infoArray[10];
		
		//キャッシュされている場合は既読、公開ゲートウェイモードの場合はクッキーがあれば既読とする
		if(!public_gateway_mode) {
			if(existCache(this))
				this.status = READ;
		
			//クッキーから更新状況を確認
			if(cookie && this.status == READ) {
				for(var i = 0; i < cookie.length; i++) {
					if(cookie[i].path == this.path && cookie[i].value < this.stamp) {
						this.status = UPDATE;
						break;
					}
				}
			}
		} else {
			if(cookie) {
				for(var i = 0; i < cookie.length; i++) {
					if(cookie[i].path == this.path) {
						if(cookie[i].value < this.stamp)
							this.status = UPDATE;
						else
							this.status = READ;
						
						break;
					}
				}
			}
		}
	} catch(e) {
		//do nothing
	}
	//----------------------------------------
	
	/*
	 *
	 *
	 */
	this.getPropertyForSort = function(name) {
		var val = null;
		
		if(name == "status")
			val = this.status;
		else if(name == "stamp")
			val = this.stamp;
		else if(name == "title")
			val = this.title;
		else if(name == "sugtag")
			val = this.sugtag;
		else if(name == "records")
			val = parseInt(this.records);
		else if(name == "size")
			val = parseInt(this.size);
		
		return val;
	}
	
	/*
	 * タグと想起タグを連結して文字列として返します。
	 *
	 * @return
	 */
	this.getTagAndSugtag = function() {
		var str = "";
		var tagArray = this.getTagAndSugtagList();
		
		for(var i = 0; i < tagArray.length; i++) {
			str += tagArray[i];
			
			if(i != tagArray.length - 1)
				str += " ";
		}
		
		return str;
	}
	
	/*
	 * タグと想起タグを連結して配列で返します。
	 *
	 * @return
	 */
	this.getTagAndSugtagList = function() {
		var array = new Array();
		
		if(this.sugtag && this.sugtag.match(/[^\s]/)) {
				
			var temp = this.sugtag.split(" ");
			
			for(var i = 0; i < temp.length; i++) {
				if(!contain(array, temp[i]))
					array.push(temp[i]);
			}
		}
		
		if(this.tag && this.tag.match(/[^\s]/)) {
			
			var temp = this.tag.split(" ");
			
			for(var i = 0; i < temp.length; i++) {
				if(!contain(array, temp[i]))
					array.push(temp[i]);
			}
		}
		
		return array;
	}
}